package com.community.huiju.controller;

import com.community.commom.constant.Constant;
import com.community.commom.mode.ResponseBean;
import com.community.huiju.common.code.cache.AppkeyCache;
import com.community.huiju.config.entity.UserElement;
import com.community.huiju.model.TaUser;
import com.community.huiju.service.ITaUserService;
import com.community.huiju.vo.TaUserVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.catalina.User;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpSession;
import javax.xml.crypto.dsig.keyinfo.PGPData;

/**
 * 用户控制器
 * @author weiximei
 */
@RestController
@RefreshScope
@RequestMapping("/")
@Api(value = "用户相关操作的API",description = "用户相关操作的API")
public class UserController {

    @Autowired
    private ITaUserService iTaUserService;

    @ApiOperation(value = "登录", notes = "根据登录名和验证码")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path",dataType = "String",name = "communityId",value = "小区"),
            @ApiImplicitParam(paramType = "query",dataType = "String",name = "loginName",value = "登陆名(手机号)"),
            @ApiImplicitParam(paramType = "query",dataType = "String",name = "code",value = "验证码")
    })
    @RequestMapping(value = "/user/login/{communityId}",method = RequestMethod.POST)
    public ResponseBean login(@RequestParam(value = "loginName") String loginName,
                              @RequestParam(value = "code",defaultValue = "") String code,
                              @PathVariable(value = "communityId") String communityId,
                              HttpSession session){
        ResponseBean responseBean = iTaUserService.login(loginName,communityId,code);
        TaUserVO userVO = (TaUserVO) responseBean.getData();

        if (null != userVO) {
            UserElement userElement = new UserElement();
            BeanUtils.copyProperties(userVO,userElement);
            session.setAttribute(Constant.APP_USER_SESSION,userElement);
            userVO.setToken(session.getId());
        }
        return responseBean;

    }
    @ApiOperation(value = "修改手机号", notes = "修改手机号")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query",dataType = "String",name = "phone",value = "登陆(手机号)"),
            @ApiImplicitParam(paramType = "query",dataType = "String",name = "code",value = "验证码")
    })
            @RequestMapping(value = "/user/phone",method = RequestMethod.PUT)
    public ResponseBean update(@RequestParam(value = "phone") String phone,@RequestParam(value = "code")String code,HttpSession session){
        ResponseBean responseBean = new ResponseBean();
        UserElement userElement = (UserElement) session.getAttribute(Constant.APP_USER_SESSION);
        Integer userId=userElement.getId();
        ResponseBean response=iTaUserService.selectloginName(userId,phone,code);
        return response;
    }


}
