package com.community.huiju.service.impl;

import com.community.commom.mode.ResponseBean;
import com.community.commom.utils.AccountValidatorUtil;
import com.community.commom.utils.MD5Utils;
import com.community.huiju.common.code.cache.AppkeyCache;
import com.community.huiju.dao.TaUserMapper;
import com.community.huiju.model.TaUser;
import com.community.huiju.service.ITaUserService;
import com.community.huiju.vo.TaUserVO;
import com.google.common.collect.Maps;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.Map;

/**
 * 用户业务 实现
 * @author weiximei
 */
@Service("iTaUserService")
@Slf4j
public class TaUserServiceImpl implements ITaUserService {

    @Autowired
    private TaUserMapper taUserMapper;

    @Transactional
    @Override
    public ResponseBean login(TaUser user) {
        ResponseBean response = new ResponseBean();
        log.info("{} 手机号校验结果: {}",user.getLoginName(),AccountValidatorUtil.isPhone(user.getLoginName()));
        if (!AccountValidatorUtil.isPhone(user.getLoginName())){
            response.addError("请输入正取的手机号!");
            return response;
        }
        Map<String,Object> map = Maps.newHashMap();
        map.put("loginName",user.getLoginName());
        map.put("loginPassword",MD5Utils.encode(user.getLoginPassword()));
        TaUser currentUser = taUserMapper.selectByLoginNameAndByLoginPassword(map);
        if (null != currentUser){
            response.addSuccess(currentUser);
            return response;
        }else {
            // 1.用户在库中,不在则注册一个
            TaUser isTaUser = taUserMapper.selectByLoginName(map);
            if (null == isTaUser) {
                ResponseBean result = register(user);
                response.addSuccess(response.getData());
            }else {
                response.addError("用户名或者密码错误!");
            }

        }
        return response;
    }

    @Override
    public ResponseBean login(String loginName,String communityId,String code) {
        ResponseBean response = new ResponseBean();
        String phoneCode = (String) AppkeyCache.getCache(loginName);
        if (!phoneCode.equals(code)) {
            response.addError("验证码错误!");
            return response;
        }
        // 设置验证码为null字符
        AppkeyCache.setCache(loginName,"null");
        log.info("{} 手机号校验结果: {}",loginName,AccountValidatorUtil.isPhone(loginName));
        if (!AccountValidatorUtil.isPhone(loginName)){
            response.addError("请输入正取的手机号!");
            return response;
        }
        if (StringUtils.isBlank(communityId)) {
            response.addError("请选择小区!");
            return response;
        }
        if (StringUtils.isBlank(code)) {
            response.addError("请输入验证码!");
            return response;
        }

        Map<String,Object> map = Maps.newHashMap();
        map.put("loginName",loginName);
        TaUser currentUser = taUserMapper.selectByLoginName(map);
        if (null != currentUser){
            if (!communityId.equals(currentUser.getCommunityId()+"")) {
                response.addError("用户不在此小区!");
                return response;
            }
            TaUserVO taUserVO = new TaUserVO();
            BeanUtils.copyProperties(currentUser,taUserVO);
            response.addSuccess(taUserVO);
            return response;
        }else {
            TaUser user = new TaUser();
            user.setLoginName(loginName);
            ResponseBean result = register(user);
            response.addSuccess(result.getData());
        }
        return response;
    }

    @Transactional
    @Override
    public ResponseBean register(TaUser user) {

        // TODO 注册逻辑需要完善
        /**
         * 1.自动生成账号的基本信息
         * 2.匹配资料库 已认证 未认证
         * 2.角色类型
         *
         * 具体看原型图
         *
         */

        ResponseBean<TaUserVO> response = new ResponseBean();
        // 开始注册
        user.setCreateDate(new Date());
        user.setUpdateDate(new Date());
        user.setStatus("1");
        user.setAcceptAgreementStatus("1");
        user.setUserName(user.getLoginName());
        user.setRemark("这是系统自动注册!");
        user.setCommunityId(3);
        user.setVerifyStatus("1");
        //user.setLoginPassword(MD5Utils.encode(user.getLoginPassword()));
        taUserMapper.insertSelective(user);

        TaUserVO taUserVO = new TaUserVO();
        BeanUtils.copyProperties(user,taUserVO);
        response.addSuccess(taUserVO);
        return response;
    }

    @Override
    public ResponseBean selectloginName(Integer id, String phone, String code) {
        ResponseBean response = new ResponseBean();
        TaUser user=taUserMapper.selectByPrimaryKey(id);
        //系统验证码
        String  codes= (String) AppkeyCache.getCache(user.getLoginName());
        //用户电话
            /*String  phones=user.getLoginName();*/
        if(codes.equals(code)){
            TaUser taUser=new TaUser();
            taUser.setLoginName(phone);
            taUser.setId(user.getId());
            taUserMapper.ubdateLongName(taUser);
             response.addSuccess("修改成功");
            AppkeyCache.setCache(user.getLoginName(),"null");
            return response;
        }else {
            response.addError("验证码错误");
            return response;
        }



    }

}
