/*==============================================================*/
/* DBMS name:      MySQL 5.0                                    */
/* Created on:     2018/10/18 13:41:38                          */
/*==============================================================*/


drop table if exists sys_dictionary;

drop table if exists sys_nation;

drop table if exists ta_agreement;

drop table if exists ta_sys_role;

drop table if exists ta_sys_user_role;

drop table if exists ta_user;

drop table if exists td_images;

drop table if exists to_banner;

drop table if exists to_communities;

drop table if exists to_sys_menu;

drop table if exists to_sys_operate_log;

drop table if exists to_sys_role;

drop table if exists to_sys_role_menu;

drop table if exists to_sys_user_role;

drop table if exists to_user;

drop table if exists tp_activity;

drop table if exists tp_activity_sign_up;

drop table if exists tp_announcement;

drop table if exists tp_announcement_tel;

drop table if exists tp_bill;

drop table if exists tp_bill_invoice;

drop table if exists tp_bill_statement;

drop table if exists tp_building_owner_info;

drop table if exists tp_message;

drop table if exists tp_message_type;

drop table if exists tp_social_setting;

drop table if exists tp_social_view;

drop table if exists tp_sys_menu;

drop table if exists tp_sys_property_log;

drop table if exists tp_sys_role;

drop table if exists tp_sys_role_menu;

drop table if exists tp_sys_user_role;

drop table if exists tp_ticket;

drop table if exists tp_ticket_record;

drop table if exists tp_ticket_record_comment;

drop table if exists tp_transaction;

drop table if exists tp_user;

drop table if exists tp_user_community;

/*==============================================================*/
/* Table: sys_dictionary                                        */
/*==============================================================*/
create table sys_dictionary
(
   id                   int(11) not null auto_increment,
   code                 varchar(50) character set utf8 comment '字典编码',
   name                 varchar(50) character set utf8 comment '字典名称',
   group_id             varchar(32) character set utf8 comment '分组id，就是父id',
   sort                 int(2) default NULL comment '排序',
   primary key (id)
)
ENGINE = InnoDB AUTO_INCREMENT = 949 CHARACTER SET = utf8 COLLATE = utf8_unicode_ci ROW_FORMAT = Compact;

alter table sys_dictionary comment '数据字典表';

/*==============================================================*/
/* Table: sys_nation                                            */
/*==============================================================*/
create table sys_nation
(
   id                   int(11) not null auto_increment,
   code                 varchar(40) comment '地区代码',
   province             varchar(40) comment '省份',
   city                 varchar(40) comment '城市',
   parent_id            int(11) comment '父级行政区划ID',
   create_time          datetime comment '创建时间',
   district             varchar(40) comment '县/区',
   last_update_time     datetime comment '最后修改时间',
   operator             int,
   operator_ip          varchar(25),
   primary key (id)
);

alter table sys_nation comment '国家行政区划表';

/*==============================================================*/
/* Table: ta_agreement                                          */
/*==============================================================*/
create table ta_agreement
(
   id                   int(11) not null auto_increment,
   user_agreement       text comment '用户协议信息',
   protection_statement text comment '保护声明',
   primary key (id)
);

alter table ta_agreement comment 'app协议表';

/*==============================================================*/
/* Table: ta_sys_role                                           */
/*==============================================================*/
create table ta_sys_role
(
   id                   int(11) not null auto_increment,
   role_name            varchar(50) comment '角色名称',
   description          varchar(255) comment '描述',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table ta_sys_role comment 'app端角色';

/*==============================================================*/
/* Table: ta_sys_user_role                                      */
/*==============================================================*/
create table ta_sys_user_role
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   user_id              int(11) default NULL comment '用户ID',
   role_id              int(11) default NULL comment '角色ID',
   primary key (id)
)
ENGINE = InnoDB AUTO_INCREMENT = 799 CHARACTER SET = utf8 COLLATE = utf8_unicode_ci ROW_FORMAT = Compact;

alter table ta_sys_user_role comment 'app端用户是那些角色';

/*==============================================================*/
/* Table: ta_user                                               */
/*==============================================================*/
create table ta_user
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   building_owner_info_id int(11) comment '楼栋业主资料信息id',
   head_portrait        varchar(225) comment '头像',
   user_name            varchar(50) comment '用户姓名',
   login_name           varchar(50) comment '登录账号就是手机号确保唯一',
   login_password       varchar(225) comment '登录密码',
   email                varchar(225) comment '邮箱',
   gender               char(1) comment '性别 1：男   2：女',
   status               char(1) comment '1 有效 0 无效(逻辑删除)',
   remark               varchar(225) comment '备注',
   parent_id            int(11) comment '上级目录id存在，表示是这个id下的租客或家属',
   accept_agreement_status char(1) comment '接受协议状态  0 是未接受 1是已接受',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table ta_user comment '住户app端用户表';

/*==============================================================*/
/* Table: td_images                                             */
/*==============================================================*/
create table td_images
(
   id                   int(11) not null auto_increment,
   image_url            varchar(225) comment '图片路径',
   uuid                 int(11) comment '图片关联的内容的id  根据类型来判断',
   type                 char(1) comment '类型 ：  1是公告 2 是活动  可添加',
   create_user          int(11) comment '创建人',
   create_time          datetime comment '创建时间',
   primary key (id)
);

alter table td_images comment '图片表';

/*==============================================================*/
/* Table: to_banner                                             */
/*==============================================================*/
create table to_banner
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id  （保留字段）',
   banner_description   varchar(225) comment 'banner的跳转描述',
   sort                 int(2) comment '排序',
   banner_cover         varchar(225) comment 'banner图',
   banner_position      int(11) comment 'banner位，取字典表banner',
   eff_time             datetime comment '生效时间',
   exp_time             datetime comment '失效时间',
   banner_type          char(1) comment 'banner类型： 1 是 外部超链接 2 是 自写文章',
   external_link        varchar(225) comment '外部超链接',
   banner_title         varchar(225) comment 'banner标题',
   banner_content       text comment 'banner内容',
   banner_img           varchar(225) comment 'banner文章配图',
   primary key (id)
);

alter table to_banner comment '所有小区的广告位设置表';

/*==============================================================*/
/* Table: to_communities                                        */
/*==============================================================*/
create table to_communities
(
   id                   int(11) not null auto_increment,
   community_name       varchar(225) comment '小区名称',
   community_alias      varchar(225) comment '小区别名',
   province_id          int(11) comment '省份id',
   city_id              int(11),
   district_id          int(11) comment '县/区id',
   longitude            varchar(225) comment '经度',
   latitude             varchar(225) comment '纬度',
   primary key (id)
);

alter table to_communities comment '所有小区表';

/*==============================================================*/
/* Table: to_sys_menu                                           */
/*==============================================================*/
create table to_sys_menu
(
   id                   int(4) not null auto_increment comment '菜单ID',
   menu_name            varchar(200) character set utf8 comment '菜单名称',
   menu_url             varchar(200) character set utf8 comment '菜单链接',
   menu_icon            varchar(100) character set utf8 comment '菜单图标',
   parent_id            int(11) default NULL comment '父级菜单ID',
   sort                 int(8) default NULL comment '排序',
   menu_type            char(2) character set utf8 comment '菜单类型 0 页面菜单  1功能菜单',
   status               char(2) character set utf8 comment '状态 0正常 9 删除',
   primary key (id)
)
ENGINE = InnoDB AUTO_INCREMENT = 565 CHARACTER SET = utf8 COLLATE = utf8_unicode_ci ROW_FORMAT = Compact;

alter table to_sys_menu comment '运营web端菜单';

/*==============================================================*/
/* Table: to_sys_operate_log                                    */
/*==============================================================*/
create table to_sys_operate_log
(
   id                   int(11) not null auto_increment,
   module               varchar(225) comment '访问模块',
   operate_content      varchar(225) comment '操作内容',
   operate_time         datetime comment '操作时间',
   operator             int(11) comment '操作人',
   operator_ip          varchar(50) comment '操作ip',
   primary key (id)
);

alter table to_sys_operate_log comment '运营web端记录操作日志表';

/*==============================================================*/
/* Table: to_sys_role                                           */
/*==============================================================*/
create table to_sys_role
(
   id                   int(11) not null auto_increment,
   role_name            varchar(50) comment '角色名称',
   description          varchar(255) comment '描述',
   status               char(10) comment '逻辑删除状态',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table to_sys_role comment '运营web端角色';

/*==============================================================*/
/* Table: to_sys_role_menu                                      */
/*==============================================================*/
create table to_sys_role_menu
(
   id                   int(11) not null auto_increment,
   role_id              int(11) default NULL comment '角色ID',
   menu_id              int(11) default NULL comment '菜单ID',
   primary key (id)
)
ENGINE = InnoDB AUTO_INCREMENT = 168598 CHARACTER SET = utf8 COLLATE = utf8_unicode_ci ROW_FORMAT = Compact;

alter table to_sys_role_menu comment '运营端角色可查看的菜单';

/*==============================================================*/
/* Table: to_sys_user_role                                      */
/*==============================================================*/
create table to_sys_user_role
(
   id                   int(11) not null auto_increment,
   user_id              int(11) default NULL comment '用户ID',
   role_id              int(11) default NULL comment '角色ID',
   primary key (id)
)
ENGINE = InnoDB AUTO_INCREMENT = 799 CHARACTER SET = utf8 COLLATE = utf8_unicode_ci ROW_FORMAT = Compact;

alter table to_sys_user_role comment '运营web端用户是那些角色';

/*==============================================================*/
/* Table: to_user                                               */
/*==============================================================*/
create table to_user
(
   id                   int(11) not null auto_increment,
   user_name            varchar(50) comment '用户姓名',
   login_name           varchar(50) comment '登录账号就是手机号确保唯一',
   login_password       varchar(225) comment '登录密码',
   email                varchar(225) comment '邮箱',
   head_portrait        varchar(225) comment '头像',
   remark               varchar(255) comment '备注',
   status               char(1) comment '1 有效 0 无效(逻辑删除)',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table to_user comment '运营web端用户表';

/*==============================================================*/
/* Table: tp_activity                                           */
/*==============================================================*/
create table tp_activity
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   activity_title       varchar(225) comment '活动标题',
   activity_carousel_img varchar(225) comment '轮播图',
   activity_content     varchar(225) comment '活动内容',
   sort                 int(8) comment '排序',
   sign_up_count        int(11) comment '报名人数统计',
   sign_up_max          int(11) default 0 comment '报名人数上限（0 是无上限）',
   view_count           int(11) comment '查看人数',
   registration_start_time datetime comment '报名开始时间',
   registration_end_time2 datetime comment '报名结束时间',
   activity_start_time  datetime comment '活动开始时间',
   activity_end_time    datetime comment '活动结束时间',
   status               char(1) comment '0 是已作废 1 是已发布   2 是草稿 3 是已修改',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table tp_activity comment '物业web端活动表';

/*==============================================================*/
/* Table: tp_activity_sign_up                                   */
/*==============================================================*/
create table tp_activity_sign_up
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   activity_id          int(11) comment '活动id',
   ta_user_id           int(11) comment '住户用户id',
   sign_up_time         datetime comment '报名时间',
   remark               varchar(225) comment '备注',
   primary key (id)
);

alter table tp_activity_sign_up comment '物业web端活动报名表';

/*==============================================================*/
/* Table: tp_announcement                                       */
/*==============================================================*/
create table tp_announcement
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   announcement_title   varchar(225) comment '公告标题',
   announcement_carousel_img varchar(225) comment '轮播图',
   announcement_content varchar(225) comment '公告内容',
   sort                 int(8) comment '排序',
   view_count           int(11) comment '查看人数',
   set_up_carousel      char(1) comment '是否设置为轮播  保留字段',
   status               char(1) comment '0 是已作废 1 是已发布   2 是草稿 3 是已修改',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table tp_announcement comment '物业web端公告表';

/*==============================================================*/
/* Table: tp_announcement_tel                                   */
/*==============================================================*/
create table tp_announcement_tel
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   name                 varchar(50) comment '电话名称',
   tel                  varchar(50),
   remark               char(10),
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table tp_announcement_tel comment '物业号码表';

/*==============================================================*/
/* Table: tp_bill                                               */
/*==============================================================*/
create table tp_bill
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   bill_name            varchar(50) comment '收费项名称',
   bill_explain         varchar(225) comment '缴费项说明',
   pay_price            char(10),
   pay_total_num        int(15) comment '应缴户数',
   payed_num            int(15) comment '已缴户数',
   unpayed_num          int(15) comment '未缴户数',
   bill_status          char(1) comment '项目状态 0：正在收费  1：收费完成  2： 草稿 3：正在收费',
   end_date             datetime comment '截止时间',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table tp_bill comment '缴费项表';

/*==============================================================*/
/* Table: tp_bill_invoice                                       */
/*==============================================================*/
create table tp_bill_invoice
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   bill_id              int(11) comment '收费项id',
   building_owner_info_id int(11) comment '楼栋业主资料信息id',
   ta_user_id           int(11) comment 'app用户id',
   bill_invoice_explain varchar(225) comment '收费说明',
   pay_price            int(15) comment '收费金额',
   bill_statement_id    int(11) comment '账单流水id',
   bill_status          char(1) comment '缴费状态  0：未缴费  1：已线上缴费 2：已线下缴费',
   pay_name             varchar(50) comment '缴费人',
   pay_date             datetime comment '缴费时间',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table tp_bill_invoice comment '缴费单';

/*==============================================================*/
/* Table: tp_bill_statement                                     */
/*==============================================================*/
create table tp_bill_statement
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   bill_invoice_id      int(11) comment '缴费单id',
   ta_user_id           int(11) comment 'app 用户id',
   pay_price            int(15) comment '收费金额',
   pay_name             varchar(50) comment '缴费人',
   pay_remark           varchar(225) comment '缴费备注',
   pay_type             char(1) comment '缴费方式  0：微信支付  1：线下缴费',
   create_time          datetime comment '生成流水时间',
   primary key (id)
);

alter table tp_bill_statement comment '账单流水表';

/*==============================================================*/
/* Table: tp_building_owner_info                                */
/*==============================================================*/
create table tp_building_owner_info
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   id_card              varchar(225) comment '身份证号码',
   building             varchar(225) comment '楼栋',
   unit                 varchar(225) comment '单元',
   level                varchar(225) comment '楼层',
   room_no              varchar(225) comment '户号',
   owner_name           varchar(225) comment '业主姓名',
   owner_tel            varchar(225) comment '业主手机号',
   gender               char(1) comment '性别 1：男   2：女',
   pair_status          char(1) comment '关联状态   0 未关联  1 是已关联',
   verify_status        char(1) comment '认证状态  0 是未认证    1是认证通过   2是已作废',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table tp_building_owner_info comment '楼栋业主资料信息表';

/*==============================================================*/
/* Table: tp_message                                            */
/*==============================================================*/
create table tp_message
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   ta_user_id           int(11) comment 'app 端用户id',
   message_type         char(1) comment '消息类型  1：工单类型  2：认证类型  3：管理类型  4： 下载类型',
   advice_type          char(1) comment '通知方式  1 是app内通知  2是短信通知 3 是通知栏消息  4 是 web端消息',
   to_user_id           int(11) comment '接收人id',
   source               char(1) comment '来源 1 是app端  2是物业端',
   message_content      varchar(225) comment '消息内容',
   status               char(1) comment '状态 0 是有效 1是无效',
   result               varchar(1) comment '推送结果',
   meaasge_type         varchar(1) comment '事件类型',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table tp_message comment '物业端消息表';

/*==============================================================*/
/* Table: tp_message_type                                       */
/*==============================================================*/
create table tp_message_type
(
   id                   int(11) not null auto_increment,
   name                 varchar(225) comment '事件名称',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table tp_message_type comment '事件类型表';

/*==============================================================*/
/* Table: tp_social_setting                                     */
/*==============================================================*/
create table tp_social_setting
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   social_type          varchar(80) comment '社交类型： announcement 表示公告  activity 表示活动',
   carousel_num         int(11) comment '轮播数量',
   primary key (id)
);

alter table tp_social_setting comment '物业端社交设置表 （设置住户端公告和活动轮播数）';

/*==============================================================*/
/* Table: tp_social_view                                        */
/*==============================================================*/
create table tp_social_view
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   uuid                 int(11) comment '公告id 或者是 活动id 或者是租赁id',
   social_type          varchar(80) comment '社交类型： announcement 表示公告  activity 表示活动 lease 表示二手租赁',
   ta_user_id           int(11) comment '住户端app用户id',
   remark               varchar(225) comment '备注',
   create_date          datetime comment '创建时间',
   primary key (id)
);

alter table tp_social_view comment '物业web端公告和活动查看数量记录表';

/*==============================================================*/
/* Table: tp_sys_menu                                           */
/*==============================================================*/
create table tp_sys_menu
(
   id                   int(4) not null auto_increment comment '菜单ID',
   community_id         int(11) comment '小区id',
   menu_name            varchar(200) character set utf8 comment '菜单名称',
   menu_url             varchar(200) character set utf8 comment '菜单链接',
   menu_icon            varchar(100) character set utf8 comment '菜单图标',
   parent_id            int(11) default NULL comment '父级菜单ID',
   sort                 int(8) default NULL comment '排序',
   menu_type            char(2) character set utf8 comment '菜单类型 0 页面菜单  1功能菜单',
   status               char(2) character set utf8 comment '状态 0正常 9 删除',
   primary key (id)
)
ENGINE = InnoDB AUTO_INCREMENT = 565 CHARACTER SET = utf8 COLLATE = utf8_unicode_ci ROW_FORMAT = Compact;

alter table tp_sys_menu comment '物业web端菜单表';

/*==============================================================*/
/* Table: tp_sys_property_log                                   */
/*==============================================================*/
create table tp_sys_property_log
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   module               varchar(225) comment '访问模块',
   operate_content      varchar(225) comment '操作内容',
   operate_time         datetime comment '操作时间',
   operator             int(11) comment '操作人',
   operator_ip          varchar(50) comment '操作ip',
   primary key (id)
);

alter table tp_sys_property_log comment '物业web端记录操作日志表';

/*==============================================================*/
/* Table: tp_sys_role                                           */
/*==============================================================*/
create table tp_sys_role
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   role_name            varchar(50) comment '角色名称',
   description          varchar(255) comment '描述',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table tp_sys_role comment '物业web端角色表';

/*==============================================================*/
/* Table: tp_sys_role_menu                                      */
/*==============================================================*/
create table tp_sys_role_menu
(
   id                   int(11) not null auto_increment,
   community_id         int(11),
   role_id              int(11) default NULL comment '角色ID',
   menu_id              int(11) default NULL comment '菜单ID',
   primary key (id)
)
ENGINE = InnoDB AUTO_INCREMENT = 168598 CHARACTER SET = utf8 COLLATE = utf8_unicode_ci ROW_FORMAT = Compact;

alter table tp_sys_role_menu comment '物业端角色可查看的菜单';

/*==============================================================*/
/* Table: tp_sys_user_role                                      */
/*==============================================================*/
create table tp_sys_user_role
(
   id                   int(11) not null auto_increment,
   community_id         int(11),
   user_id              int(11) default NULL comment '用户ID',
   role_id              int(11) default NULL comment '角色ID',
   primary key (id)
)
ENGINE = InnoDB AUTO_INCREMENT = 799 CHARACTER SET = utf8 COLLATE = utf8_unicode_ci ROW_FORMAT = Compact;

alter table tp_sys_user_role comment '物业web端用户是那些角色';

/*==============================================================*/
/* Table: tp_ticket                                             */
/*==============================================================*/
create table tp_ticket
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   ta_user_id           int(11) comment '住户app的id',
   ticket_title         varchar(225) comment '工单标题',
   ticket_content       varchar(225) comment '工单内容',
   status               char(1) comment '流转状态      0:待分配  1:拒绝受理 2:待处理 3:正在处理 4:待评价 5:已评价 6:被终止',
   type                 char(1) comment '类型    0 代表 报修  1 代表 投诉  2代表 联系单   字典',
   repair_type          char(1) comment '报修类型：0:公共区域  1: 房屋质量  2::户内设施  PS : 报修的情况下才有报修类型 加表',
   ticket_match_img1    varchar(225) comment '工单配图',
   ticket_match_img2    varchar(225) comment '工单配图',
   ticket_match_img3    varchar(225) comment '工单配图',
   ticket_match_img4    varchar(225) comment '工单配图',
   ticket_match_img5    varchar(225) comment '工单配图',
   tp_user_id           int(11) comment '受理人id 也就是物业的用户id   加 中间关系表',
   score                varchar(50) comment '评分',
   comment              varchar(225) comment '评语',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table tp_ticket comment '工单表';

/*==============================================================*/
/* Table: tp_ticket_record                                      */
/*==============================================================*/
create table tp_ticket_record
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   ticket_id            int(11) comment '工单id',
   status               char(1) comment '流转状态      0:待分配  1:拒绝受理 2:待处理 3:正在处理 4:待评价 5:已评价 6:被终止',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   primary key (id)
);

alter table tp_ticket_record comment '工单处理表';

/*==============================================================*/
/* Table: tp_ticket_record_comment                              */
/*==============================================================*/
create table tp_ticket_record_comment
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   ticker_id            int(11) comment '工单id',
   ticket_record_id     int(11) comment '工单记录id',
   uuid                 int(11) comment '追问人id(tp_user_id也就是物业用户)   或者是 发起人id(ta_user_id也就是住户app的id)',
   user_type            char(1) comment '用户类型： 0：追问人  1：发起人',
   content              varchar(225) comment '追问内容或者回复内容',
   parent_id            int(11) comment '回复的是哪条记录的id。 0表示当前状态下的第一条追问记录',
   user_name            varchar(225) comment '用户姓名',
   create_date          datetime comment '创建时间',
   primary key (id)
);

alter table tp_ticket_record_comment comment '物业端工单追问表';

/*==============================================================*/
/* Table: tp_transaction                                        */
/*==============================================================*/
create table tp_transaction
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   ta_user_id           int(11) comment '住户app的用户id',
   transaction_title    varchar(225) comment '交易标题',
   transaction_content  varchar(225) comment '交易内容',
   transaction_match_img1 varchar(225) comment '交易配图',
   activity_match_img3  varchar(225) comment '交易配图',
   activity_match_img4  varchar(225) comment '交易配图',
   activity_match_img5  varchar(225) comment '交易配图',
   activity_match_img6  varchar(225) comment '交易配图',
   view_count           int(11) comment '查看人数',
   status               char(1) comment '0 是已作废 1 是已发布   ',
   type                 char(1) comment '0 代表 二手（卖二手物品）  1 是代表 求购 （买二手物品） 2 是代表 租赁（租二手物品）',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table tp_transaction comment '物业web端二手交易表';

/*==============================================================*/
/* Table: tp_user                                               */
/*==============================================================*/
create table tp_user
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   user_name            varchar(50) comment '用户姓名',
   login_name           varchar(50) comment '登录账号就是手机号确保唯一',
   login_password       varchar(225) comment '登录密码',
   status               char(1) comment '1 有效 0 无效(逻辑删除)',
   remark               varchar(225) comment '备注',
   email                varchar(225) comment '邮箱',
   head_portrait        varchar(225) comment '头像',
   create_user          int(11) comment '创建人',
   create_date          datetime comment '创建时间',
   update_user          int(11) comment '更新人',
   update_date          datetime comment '更新时间',
   primary key (id)
);

alter table tp_user comment '物业web端用户表';

/*==============================================================*/
/* Table: tp_user_community                                     */
/*==============================================================*/
create table tp_user_community
(
   id                   int(11) not null auto_increment,
   community_id         int(11) comment '小区id',
   tp_user_id           int(11) comment '物业端用户id',
   primary key (id)
);

alter table tp_user_community comment '物业端用户和小区关联表';

